﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.Windows.Controls.Primitives;
using DlhSoft.Windows.Controls;
using DlhSoft.Windows.Data;

namespace GanttChartTaskListViewEffortPartitionsSample
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            InitializeComponent();

            ObservableCollection<TaskItem> taskItems = new ObservableCollection<TaskItem>
            {
                new CustomTaskItem { Content = "Task 1", IndexString = "1" },
                new CustomTaskItem { Content = "Task 1.1", Indentation = 1, Start = DateTime.Today, Effort = TimeSpan.Parse("08:00:00"), CompletedEffort = TimeSpan.Parse("04:00:00"), IndexString = "2" },
                new CustomTaskItem { Content = "Task 1.2", Indentation = 1, IndexString = "3" },
                new CustomTaskItem { Content = "Task 1.2.1", Indentation = 2, Start = DateTime.Today, Effort = TimeSpan.Parse("08:00:00"), IndexString = "4" },
                new CustomTaskItem { Content = "Task 1.2.2", Indentation = 2, Start = DateTime.Today, Effort = TimeSpan.Parse("16:00:00"), IndexString = "5" },
                new CustomTaskItem { Content = "Task 2", IsExpanded = true, IndexString = "6" },
                new CustomTaskItem { Content = "Task 2.1", Indentation = 1, Start = DateTime.Today, Effort = TimeSpan.Parse("16:00:00"), IsCompleted = true, IndexString = "7" },
                new CustomTaskItem { Content = "Task 2.2", Indentation = 1, Start = DateTime.Today, Effort = TimeSpan.Parse("08:00:00"), CompletedEffort = TimeSpan.Parse("06:00:00"), IndexString = "8" },
                new CustomTaskItem { Content = "Task 2.3", Indentation = 1, IsExpanded = true, IndexString = "9", PredecessorsString = "8" },
                new CustomTaskItem { Content = "Task 2.3.1", Indentation = 2, Start = DateTime.Today, Effort = TimeSpan.Parse("1.16:00:00"), IndexString = "10", Cost = 2000 },
                new CustomTaskItem { Content = "Task 2.3.2", Indentation = 2, Start = DateTime.Today, Effort = TimeSpan.Parse("08:00:00"), IndexString = "11", PredecessorsString = "10" },
                new CustomTaskItem { Content = "Task 3", Start = DateTime.Today, Effort = TimeSpan.Parse("12:30:00"), CompletedEffort = TimeSpan.Parse("02:30:00"), IndexString = "12", PredecessorsString = "9, 11SS+12" },
                new CustomTaskItem { Content = "Task 4", Start = DateTime.Today, Effort = TimeSpan.Parse("16:00:00"), AssignmentsString = "Resource 1", IndexString = "13" },
                new CustomTaskItem { Content = "Task 5", Start = DateTime.Today, Effort = TimeSpan.Parse("20:00:00"), AssignmentsString = "Resource 1, Resource 2 [50%]", IndexString = "14" },
                new CustomTaskItem { Content = "Task 6", Start = DateTime.Today, IsMilestone = true, IndexString = "15", PredecessorsString = "14+2" },
                // This task has EffortInterruptions set to a collection of time intervals that generate acceptable task effort partitions.
                new CustomTaskItem 
                { 
                    Content = "Eff. Part. Task", Start = DateTime.Today, Effort = TimeSpan.Parse("20:00:00"), CompletedEffort = TimeSpan.Parse("08:00:00"),
                    EffortInterruptions = new ObservableCollection<TimeInterval>
                    {
                        new TimeInterval(DateTime.Today.Add(TimeSpan.Parse("12:00:00")), DateTime.Today.AddDays(1).Add(TimeSpan.Parse("10:00:00"))),
                        new TimeInterval(DateTime.Today.AddDays(2).Add(TimeSpan.Parse("14:00:00")), DateTime.Today.AddDays(3).Add(TimeSpan.Parse("12:00:00")))
                    }
                }
            };

            ObservableCollection<ResourceItem> assignableResourceItems = new ObservableCollection<ResourceItem>
            {
                new ResourceItem { Content = "Resource 1", CostPerUsage = 100, CostPerHour = 10 },
                new ResourceItem { Content = "Resource 2", CostPerHour = 20 }
            };

            GanttChartTaskListView.AssignableResourceItemsSource = assignableResourceItems;
            GanttChartTaskListView.ItemsSource = taskItems;
        }

        // Event handler for creating new effort partitioning enabled tasks when the end user executes the Insert New command of the control.
        private void GanttChartTaskListView_NewTask(object sender, NewItemEventArgs e)
        {
            e.Item = new CustomTaskItem { Content = "New Task", Start = DateTime.Today, Effort = TimeSpan.Parse("08:00:00") };
        }
    }
}
